@@ -4,7 +4,7 @@ from django_socio_grpc import proto_serializers
 from .models import UnitTestModel
 
 
-class UnitTestSerializer(proto_serializers.ModelProtoSerializer):
+class UnitTestModelSerializer(proto_serializers.ModelProtoSerializer):
     class Meta:
         model = UnitTestModel
         proto_class = grpc_model.UnitTestModel
